Nielsen helps you `chown`, `chmod`, rename, and organize TV show files.

A typical filename might be something like:
`The.Glades.S02E01.Family.Matters.HDTV.XviD-FQM.avi`, but a less annoying
filename would be `The Glades -02.01- Family Matters.avi`.

Nielsen endeavors to automatically handle these types of renaming operations,
as well as change the owner, group, and file permissions to user specified
values (which may be more useful for media streaming scenarios), and move the
files into a more hierarchical folder structure that keeps your media
directories tidy.

View the [wiki](https://github.com/IrishPrime/Nielsen/wiki) for configuration
information.

[![Build Status](https://travis-ci.org/IrishPrime/Nielsen.svg?branch=master)](https://travis-ci.org/IrishPrime/Nielsen)
